@@ -107,7 +107,17 @@
 /**
  * Number of bytes to feed to libav in one go, with padding (padding is zeroed).
  */
+#ifdef AV_INPUT_BUFFER_PADDING_SIZE
+#define PADDED_BUFFER_SIZE (BUFFER_SIZE + AV_INPUT_BUFFER_PADDING_SIZE)
+#else
+/* legacy */
 #define PADDED_BUFFER_SIZE (BUFFER_SIZE + FF_INPUT_BUFFER_PADDING_SIZE)
+#endif
+
+#ifndef AV_CODEC_FLAG_QSCALE
+#define AV_CODEC_FLAG_QSCALE CODEC_FLAG_QSCALE
+#endif
+
 
 /**
  * Global handle to MAGIC data.
@@ -355,7 +365,7 @@ create_thumbnail (AVCodecContext *pCodecCtx, int src_width, int src_height,
    encoder_codec_ctx->mb_lmin = encoder_codec_ctx->qmin * FF_QP2LAMBDA;
    encoder_codec_ctx->mb_lmax = encoder_codec_ctx->qmax * FF_QP2LAMBDA;
 #endif
-   encoder_codec_ctx->flags          = CODEC_FLAG_QSCALE;
+   encoder_codec_ctx->flags          = AV_CODEC_FLAG_QSCALE;
    encoder_codec_ctx->global_quality = encoder_codec_ctx->qmin * FF_QP2LAMBDA;
 
    dst_frame->pts     = 1;
